# -*- coding: utf-8 -*-
# Module Tortue,
#   traduction des principales commandes
#   du module standard turtle
#
# F. Goichot, décembre 2017

from turtle import *

def avance(d):
    '''fait avancer la tortue d'une longueur d (en pixels)'''
    forward(d)
    
def recule(d):
    '''fait reculer la tortue d'une longueur d (en pixels)'''
    backward(d)
    
def droite(a):
    '''fait tourner la tortue vers la droite, de l'angle a 
    (en degrés, par défaut)'''
    right(a)
    
def gauche(a):
    '''fait tourner la tortue vers la gauche, de l'angle a 
    (en degrés, par défaut)'''
    left(a)
    
def oriente(a):
    '''oriente la marche de la tortue dans la direction donnée par l'angle a
    (en degrés, par défaut) ; 0 = est, 90 = nord, etc'''
    setheading(a)
 
def leve():
    '''lève le stylo'''
    up()
    
def baisse():
    '''baisse le stylo'''
    down()
    
def va_en(x,y):
    '''déplace la tortue vers le point de coordonnées (x,y)'''
    goto(x,y)
    
def maison():
    '''ramène la tortue au point (0,0)'''
    home()
    
def cache():
    '''cache la tortue (le dessin va plus vite)'''
    hideturtle()
    
def montre():
    '''fait apparaître la tortue'''
    showturtle()
    
def efface():
    '''efface les dessins réalisés, sans modifier la position de la tortue'''
    clear()
    
def maz():
    '''mise à zéro : tout est effacé, la tortue reprend son état initial'''
    clearscreen()
    
def couleur(c):
    '''modifie la couleur des tracés qui suivent ; c est une lettre (à taper 
    entre guillemets donc), parmi les suivantes : 
    r=rouge, v=vert, n=noir, b=bleu, c=cyan'''
    lettres = ['r','v','n','b','c']
    couleurs = ['red','green','black','blue','cyan']
    for i in range(len(lettres)):
        if c == lettres[i] :
            color(couleurs[i])
            return
    print("couleur inconnue")
    
def titre(mot):
    '''définit le titre de la fenêtre de la tortue ; "mot" doit être
    une chaîne de caractères, entre guillemets donc'''
    title(mot)
    
def taille_fenetre(larg = 0.5, haut = 0.5):
    '''règle la taille de la fenêtre de la tortue ; larg et haut sont :
    - soit des nombres entre 0 et 1, compris comme des pourcentages de la
    taille de l'écran de l'ordinateur ; par défaut, larg=0.5 donc la moitié 
    de la largeur de l'écran,
    - soit des entiers, compris comme la taille en pixels'''
    setup(width = larg, height = haut)
    
def position_fenetre(debutx, debuty):
    '''régle la position de la fenêtre ; par défaut elle est centrée ;
    si debutx est positif, c'est le nombre de pixels laissés libres à gauche de la
    fenetre ; si debutx est négatif, pareil à droite ; pareil pour debuty 
    mais verticalement ; exemple : position_fenetre(0,0) la placera dans le coin
    supérieur gauche, position_fenetre(-5,-5) dans le coin inférieur droit'''
    setup(window_width(),window_height(),debutx,debuty)
    
def change_repere(xmin,ymin,xmax,ymax):
    '''définit un nouveau repère : les abscisses iront de xmin à xmax (dans la
    fenêtre disponible) et les ordonnées de ymin à ymax (idem) ; il y a d'abord
    une mise à zéro ; ATTENTION, les angles seront déformés de manière imprévisible'''
    setworldcoordinates(xmin,ymin,xmax,ymax)
    
def ecrire(texte,aligne='g',taille=8):
    '''écrit le texte à l'endroit où est la tortue ; on peut aligner à (g)auche, 
    à (d)roite ou au (c)entre ; et régler la taille des caractères'''
    alig = 'left'
    if aligne == 'd':
        alig = 'right'
    elif aligne == 'c':
        alig = 'center'
    write(texte, align = alig, font = ('Arial', taille, 'normal'))
    
def vitesse(vit):
    '''règle la vitesse de la tortue, de 1 (très lent) à 10 (très rapide) ;
    si vit=0, pas d'animation donc dessin plus rapide'''
    speed(vit)
    

